// $Id: OutputSurface.cc 6786 2007-08-04 10:29:59Z m9710797 $

#include "OutputSurface.hh"

namespace openmsx {

OutputSurface::OutputSurface()
	: surface(0)
{
}

OutputSurface::~OutputSurface()
{
}

unsigned OutputSurface::mapRGB(double dr, double dg, double db)
{
	int r = int(dr * 255.0);
	int g = int(dg * 255.0);
	int b = int(db * 255.0);
	return SDL_MapRGB(&format, r, g, b);
}

} // namespace openmsx
